
package com.sinosig.web.module.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import com.sinosig.util.feign.suport.SearchContextFeignEncode;
import com.sinosig.web.module.domain.CID;
import com.sinosig.web.module.filter.*;
import com.sinosig.web.module.feign.CIDFeignClient;
import com.sinosig.web.WebApplication.WebClientProperties;
import com.sinosig.util.feign.FeignRequestInterceptor;

@Service
public class CIDService {

    CIDFeignClient client;

    @Autowired
    public CIDService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    WebClientProperties webClientProperties) {
        if (webClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(CIDFeignClient.class,"http://" + webClientProperties.getServiceId() + "/") ;
		} else if (webClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(CIDFeignClient.class, "http://" + webClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(CID cid) {
        return client.checkKey(cid);
    }

	public CID create(CID cid) {
        return client.create(cid);
    }

    public CID get( String cid_id) {
        return client.get( cid_id);
    }

    public CID getDraft(String cid_id, CID cid) {
        return client.getDraft(cid_id, cid);
    }

    public CID update(String cid_id, CID cid) {
        return client.update(cid_id, cid);
    }

    public CID save(String cid_id, CID cid) {
        return client.save(cid_id, cid);
    }

    public boolean remove( String cid_id) {
        return client.remove( cid_id);
    }

	public Page<CID> fetchDefault(CIDSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }


}
